# PriorityQueue (PriorityQueue.sol)

View Source: [contracts/src/framework/utils/PriorityQueue.sol](../../contracts/src/framework/utils/PriorityQueue.sol)

**↗ Extends: [OnlyFromAddress](OnlyFromAddress.md)**

**PriorityQueue**

Min-heap priority queue implementation

## Structs
### Queue

```js
struct Queue {
 uint256[] heapList,
 uint256 currentSize
}
```

## Contract Members
**Constants & Variables**

```js
struct PriorityQueue.Queue public queue;
address public framework;

```

## Functions

- [()](#)
- [currentSize()](#currentsize)
- [heapList()](#heaplist)
- [insert(uint256 _element)](#insert)
- [delMin()](#delmin)
- [getMin()](#getmin)
- [percUp(struct PriorityQueue.Queue self, uint256 pointer)](#percup)
- [percDown(struct PriorityQueue.Queue self, uint256 pointer)](#percdown)
- [minChild(struct PriorityQueue.Queue self, uint256 i)](#minchild)

### 

```js
function () public nonpayable
```

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|

### currentSize

Gets num of elements in the queue

```js
function currentSize() external view
returns(uint256)
```

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|

### heapList

Gets all elements in the queue

```js
function heapList() external view
returns(uint256[])
```

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|

### insert

Inserts an element into the queue by the framework

```js
function insert(uint256 _element) external nonpayable onlyFrom 
```

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|
| _element | uint256 |  | 

### delMin

Deletes the smallest element from the queue by the framework

```js
function delMin() external nonpayable onlyFrom 
returns(uint256)
```

**Returns**

The smallest element in the priority queue

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|

### getMin

Returns the smallest element from the queue

```js
function getMin() external view
returns(uint256)
```

**Returns**

The smallest element in the priority queue

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|

### percUp

```js
function percUp(struct PriorityQueue.Queue self, uint256 pointer) private nonpayable
```

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|
| self | struct PriorityQueue.Queue |  | 
| pointer | uint256 |  | 

### percDown

```js
function percDown(struct PriorityQueue.Queue self, uint256 pointer) private nonpayable
```

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|
| self | struct PriorityQueue.Queue |  | 
| pointer | uint256 |  | 

### minChild

```js
function minChild(struct PriorityQueue.Queue self, uint256 i) private view
returns(uint256)
```

**Arguments**

| Name        | Type           | Description  |
| ------------- |------------- | -----|
| self | struct PriorityQueue.Queue |  | 
| i | uint256 |  | 

## Contracts

* [Address](Address.md)
* [Bits](Bits.md)
* [BlockController](BlockController.md)
* [BlockModel](BlockModel.md)
* [BondSize](BondSize.md)
* [ECDSA](ECDSA.md)
* [Erc20DepositVerifier](Erc20DepositVerifier.md)
* [Erc20Vault](Erc20Vault.md)
* [EthDepositVerifier](EthDepositVerifier.md)
* [EthVault](EthVault.md)
* [ExitableTimestamp](ExitableTimestamp.md)
* [ExitGameController](ExitGameController.md)
* [ExitGameRegistry](ExitGameRegistry.md)
* [ExitId](ExitId.md)
* [ExitPriority](ExitPriority.md)
* [FailFastReentrancyGuard](FailFastReentrancyGuard.md)
* [FeeClaimOutputToPaymentTxCondition](FeeClaimOutputToPaymentTxCondition.md)
* [FeeExitGame](FeeExitGame.md)
* [FungibleTokenOutputModel](FungibleTokenOutputModel.md)
* [GenericTransaction](GenericTransaction.md)
* [IERC20](IERC20.md)
* [IErc20DepositVerifier](IErc20DepositVerifier.md)
* [IEthDepositVerifier](IEthDepositVerifier.md)
* [IExitProcessor](IExitProcessor.md)
* [ISpendingCondition](ISpendingCondition.md)
* [IStateTransitionVerifier](IStateTransitionVerifier.md)
* [Math](Math.md)
* [Merkle](Merkle.md)
* [Migrations](Migrations.md)
* [MoreVpFinalization](MoreVpFinalization.md)
* [OnlyFromAddress](OnlyFromAddress.md)
* [OnlyWithValue](OnlyWithValue.md)
* [OutputId](OutputId.md)
* [Ownable](Ownable.md)
* [PaymentChallengeIFEInputSpent](PaymentChallengeIFEInputSpent.md)
* [PaymentChallengeIFENotCanonical](PaymentChallengeIFENotCanonical.md)
* [PaymentChallengeIFEOutputSpent](PaymentChallengeIFEOutputSpent.md)
* [PaymentChallengeStandardExit](PaymentChallengeStandardExit.md)
* [PaymentDeleteInFlightExit](PaymentDeleteInFlightExit.md)
* [PaymentEip712Lib](PaymentEip712Lib.md)
* [PaymentExitDataModel](PaymentExitDataModel.md)
* [PaymentExitGame](PaymentExitGame.md)
* [PaymentExitGameArgs](PaymentExitGameArgs.md)
* [PaymentInFlightExitModelUtils](PaymentInFlightExitModelUtils.md)
* [PaymentInFlightExitRouter](PaymentInFlightExitRouter.md)
* [PaymentInFlightExitRouterArgs](PaymentInFlightExitRouterArgs.md)
* [PaymentOutputToPaymentTxCondition](PaymentOutputToPaymentTxCondition.md)
* [PaymentPiggybackInFlightExit](PaymentPiggybackInFlightExit.md)
* [PaymentProcessInFlightExit](PaymentProcessInFlightExit.md)
* [PaymentProcessStandardExit](PaymentProcessStandardExit.md)
* [PaymentStandardExitRouter](PaymentStandardExitRouter.md)
* [PaymentStandardExitRouterArgs](PaymentStandardExitRouterArgs.md)
* [PaymentStartInFlightExit](PaymentStartInFlightExit.md)
* [PaymentStartStandardExit](PaymentStartStandardExit.md)
* [PaymentTransactionModel](PaymentTransactionModel.md)
* [PaymentTransactionStateTransitionVerifier](PaymentTransactionStateTransitionVerifier.md)
* [PlasmaFramework](PlasmaFramework.md)
* [PosLib](PosLib.md)
* [PriorityQueue](PriorityQueue.md)
* [Protocol](Protocol.md)
* [Quarantine](Quarantine.md)
* [RLPReader](RLPReader.md)
* [SafeERC20](SafeERC20.md)
* [SafeEthTransfer](SafeEthTransfer.md)
* [SafeMath](SafeMath.md)
* [SpendingConditionRegistry](SpendingConditionRegistry.md)
* [Vault](Vault.md)
* [VaultRegistry](VaultRegistry.md)
